@@ -1,4 +1,4 @@
-/*Copyright (c) 1993-1997 Xerox Corporation.  All Rights Reserved.
+/*Copyright (c) 1993-1998 Xerox Corporation.  All Rights Reserved.
 
   Permission to use, copy, modify  and  distribute  without  charge
   this  software,  documentation, images, etc. is granted, provided
@@ -36,6 +36,7 @@ XrmOptionDescRec op_table[] = {         /*Argument operation resource table*/
                 {"-display", ".display",   XrmoptionSepArg, (caddr_t) NULL},
                 {"-f", ".saveto",    XrmoptionSepArg, (caddr_t) NULL},
 		{"-i", ".ignore",    XrmoptionSepArg, (caddr_t) NULL},
+		{"-idt", ".ignoredt",XrmoptionIsArg,  (caddr_t) NULL},
                 {"-m", ".missing",   XrmoptionSepArg, (caddr_t) NULL},
                 {"-r", ".remote",    XrmoptionSepArg, (caddr_t) NULL},
                 {"-s", ".screens",   XrmoptionSepArg, (caddr_t) NULL},
@@ -273,6 +274,7 @@ merge_databases()
   Globals: addon            - name of file containing commands to add on
            console_checking - indicates if the check console flag was given
            database         - database containing ALL resources
+	   ignore	    - name of file containing X applications
            list             - option list of screens to save from
            missing          - name of file containing X applications
            program          - name of currently executing program
@@ -286,7 +288,7 @@ extract_options()
         char *resource,*filename,*tw_program;
         char *str_type[20];
         XrmValue value;
-        extern int console_checking;
+        extern int console_checking, ignoredt;
         extern char *addon,*ignore,*missing,*remote,*list;
 
         /*Allocate space for the names of the resources we'll be looking
@@ -334,6 +336,13 @@ extract_options()
 	    exit(1);
 	  }
 
+        /*Determine if we should ignore CDE dt* programs (-idt)*/
+        ignoredt = 0;
+        sprintf(resource,"%s.ignoredt",program);
+        if(XrmGetResource(database,resource,"xtoolplaces.ignoredt",
+                          str_type,&value) == True)
+          ignoredt = 1;
+
         /*Get missing applications list (-m)*/
         missing = NULL;
         sprintf(resource,"%s.missing",program);
