@@ -1,4 +1,4 @@
-/*Copyright (c) 1993-1997 Xerox Corporation.  All Rights Reserved.
+/*Copyright (c) 1993-1998 Xerox Corporation.  All Rights Reserved.
 
   Permission to use, copy, modify  and  distribute  without  charge
   this  software,  documentation, images, etc. is granted, provided
@@ -35,7 +35,7 @@ char hostname[50];
 Atom wm_save_yourself,wm_protocols,wm_client_machine;
 Display *display;
 Window root_window;
-extern int console_checking;
+extern int console_checking, ignoredt;
 extern char *program,*addon;
 extern FILE *fp;
 
@@ -159,6 +159,7 @@ getinfo()
         3.  it's parent is the root window
         4.  it has a WM_COMMAND property to save or is on a list specified
             with the '-m' option
+	5.  is not a CDE dt* program when the "ignore dt" switch is given
 
   Inputs:  display            - interface info to X display
            parent_window      - parent window ID of window we are examining
@@ -184,13 +185,13 @@ getinfo()
            console_checking   - indicates if the check console flag was given
            fp                 - file pointer to write window information to
 	   ignore	      - file containing X apps to NOT save
+	   ignoredt	      - indicates if we should ignore CDE dt* apps
 	   ilist	      - list of X apps to ignore
 	   inumvals	      - number of X apps in ilist
 	   missing	      - file containing X apps to make sure are saved
 	   mlist	      - list of X apps to make sure are saved
 	   mnumvals	      - number of X apps in mlist
            mult_screens       - flag indicating if saving more than 1 screen
-	   on_ignore_list     - flag indicating X app is to be ignored
            on_missing_list    - flag indicating if window is a missing app
            program            - name of currently executing program
            root_window        - root window ID
@@ -209,7 +210,7 @@ search(display,window,parent_window)
 Display *display;
 Window window,parent_window;
 {
-        int save_yourself,on_ignore_list,on_missing_list,console = 0;
+        int save_yourself,on_missing_list,console = 0;
         unsigned int num_child;
         int count,argc,group_leader = 0;
         char *command_line,*name;
@@ -222,7 +223,7 @@ Window window,parent_window;
         XWMHints *hints;
         char *combine(),*getgeom(),*getname(),*lower(),*get_emacs_name(),
 			 *fix_command2();
-	extern int inumvals, mnumvals;
+	extern int inumvals, mnumvals, ignoredt;
 	extern char *ignore, *ilist[MAXAPPS], *missing, *mlist[MAXAPPS];
 
 
@@ -236,10 +237,24 @@ Window window,parent_window;
           if(child) XFree((caddr_t) child);
         }
 
-        /*Don't report window if it doesn't have a name (in which case it's
-          probably a pop-up or unmapped child*/
-        if(name = getname(window)) XFree(name);
-        else return;
+	/*Don't report window if it doesn't have a name (in which case it's
+	  probably a pop-up or unmapped child).  Need to do this separately
+	  from the other checks because we want to free the name if the
+	  call works.*/
+	if (name = getname(window))
+	  XFree(name);
+	else
+	  return;
+
+        /*Don't report window if the app is on the ignore list or if the
+	  "-idt" or "ignoredt" resource flag is given and the window belongs
+	  to a CD dt* app.  CDE create windows which hang XNextEvent().  We
+	  can eliminate those by looking for windows with a size of 1x1 or
+	  a class of "Dtterm"*/
+        if((ignore && on_list(window, ilist, inumvals)) ||
+	   is_dtterm(window) || is_1x1(window) ||
+	   (ignoredt && is_dtapp(window)))
+	  return;
 
         /*Don't report window if it's not a group leader or isn't a top
           window*/
@@ -285,9 +300,6 @@ Window window,parent_window;
         /*Free resources*/
         if(status) XFree((caddr_t) protocols);
 
-	/*Determine if window is to be ignored*/
-	on_ignore_list = (ignore) ? on_list(window, ilist, inumvals) : 0;
-
         /*Determine if window is on missing apps list*/
 	on_missing_list = (missing) ? on_list(window, mlist, mnumvals) : 0;
 
@@ -297,13 +309,15 @@ Window window,parent_window;
           doesn't set WM_COMMAND (sheesh, even xterm does that!).  Must
           be a security feature :-{)*/
         status = XGetCommand(display,window,&argv,&argc);
-        if((status && !isnull(window) && !on_ignore_list) || on_missing_list ||
+        if((status && !isnull(window)) || on_missing_list ||
 	   is_emacs(window) || is_console(window,NULL)) {
           /*Put arguments into a single string and free up argv.  Makes it
             easier to check for things*/
           if(status) {
-            command_line = combine(argc,argv);
-            XFreeStringList(argv);
+	    if(argc) {
+	      command_line = combine(argc,argv);
+              XFreeStringList(argv);
+	    } else command_line = lower(getname(window));
           } else {
                    /*It is ASSUMED that if we have to save a window that
                     doesn't have WM_COMMAND set, it's name is the basename
