@@ -1,4 +1,4 @@
-/*Copyright (c) 1993-1997 Xerox Corporation.  All Rights Reserved.
+/*Copyright (c) 1993-1998 Xerox Corporation.  All Rights Reserved.
 
   Permission to use, copy, modify  and  distribute  without  charge
   this  software,  documentation, images, etc. is granted, provided
@@ -15,6 +15,7 @@
 */
 
 #include <stdio.h>
+#include <ctype.h>
 #include <X11/Xlib.h>
 #include <X11/Xutil.h>
 #include <X11/Xatom.h>
@@ -253,6 +254,107 @@ Window window;
         } else return(-1);
 }
 
+/*This function determines if a particular window is an dtterm window.  To
+  see if a window is an dtterm window, we check it's class.  Dtterm always sets
+  it's class to "Dtterm".  1 is returned if it is an dtterm window, 0 if it
+  isn't, -1 if there is an error in getting the class of the window.
+
+  Inputs:  window   - ID of the window that we are going to check
+  Outputs: 1 if dtterm, 0 if not dtterm, -1 if error in getting class
+  Locals:  match    - flag indicating if window is dtterm window or not
+           status   - status of get call
+           tp       - window's text property
+  Globals: display  - interface info to X display
+*/
+is_dtterm(window)
+Window window;
+{
+        int match;
+        Status status;
+        XClassHint class_hints;
+
+        /*Get window class to see if it's xterm*/
+        status = XGetClassHint(display,window,&class_hints);
+
+        if(status) {
+          match = strcmp(class_hints.res_class,"Dtterm");
+          XFree(class_hints.res_name);
+          XFree(class_hints.res_class);
+
+          return((!match)?1:0);
+        } else return(-1);
+}
+
+/*This function determines if a particular window is a window from a CDE
+  dt* app (i.e. dtmail, dtfile, etc.).  To see if a window is from a CDE
+  dt* app, we check it's class.  The class name always starts with "Dt".
+  1 is returned if it is a CDE dt* app window, 0 if it isn't, -1 if there
+  is an error in getting the class of the window.
+
+  Inputs:  window   - ID of the window that we are going to check
+  Outputs: 1 if dt* app, 0 if not, -1 if error in getting class
+  Locals:  match    - flag indicating if window is dt* app window or not
+           status   - status of get call
+           tp       - window's text property
+  Globals: display  - interface info to X display
+*/
+is_dtapp(window)
+Window window;
+{
+        int match;
+        Status status;
+        XClassHint class_hints;
+
+        /*Get window class to see if it's xterm*/
+        status = XGetClassHint(display,window,&class_hints);
+
+        if(status) {
+	  if((tolower(class_hints.res_class[0]) == 'd') &&
+	     (tolower(class_hints.res_class[1]) == 't'))
+            match = 1;
+	  else match = 0;
+
+          XFree(class_hints.res_name);
+          XFree(class_hints.res_class);
+
+          return(match);
+        } else return(-1);
+}
+
+/*This function determines if a particular window has a size of 1x1.  This
+  is the size created by CDE that will hang xtoolplaces if not caught.  I
+  don't know if any other window manager creates windows of size 1x1.  1 is
+  returned if it is a window of size 1x1, 0 if it isn't, -1 if there is an
+  error in getting the size of the window.
+
+  Inputs:  window   - ID of the window that we are going to check
+  Outputs: 1 if size = 1x1, 0 if not, -1 if error in getting size
+  Locals:  match    - flag indicating if window size = 1x1
+           status   - status of get call
+           tp       - window's text property
+  Globals: display  - interface info to X display
+*/
+is_1x1(window)
+Window window;
+{
+	int dummy;
+	unsigned int width, height, udummy;
+        Status status;
+	Window root;
+
+	/*Only get the geometry information we care about, the width & height*/
+	status = XGetGeometry(display, window, &root, &dummy, &dummy,
+			      &width, &height, &udummy, &udummy);
+
+	/*Check the width and height if we were able to get the size*/
+	if(status) {
+	  if((width == 1) && (height == 1))
+	    return(1);
+	  else
+	    return(0);
+	} else return(-1);
+}
+
 /*This function determines if a particular window is an emacs window.  To
   see if a window is an emacs window, we check it's class.  Emacs always sets
   it's class to "Emacs".  1 is returned if it is an emacs window, 0 if it
