@@ -1,4 +1,4 @@
-/*Copyright (c) 1993-1997 Xerox Corporation.  All Rights Reserved.
+/*Copyright (c) 1993-1998 Xerox Corporation.  All Rights Reserved.
 
   Permission to use, copy, modify  and  distribute  without  charge
   this  software,  documentation, images, etc. is granted, provided
@@ -14,6 +14,8 @@
   Adam Stein (adam@iset.scan.mc.xerox.com)
 */
 
+#ifdef NEED_STRDUP
+
 #include <stdio.h>
 #include "xtoolplaces.h"
 
@@ -46,3 +48,5 @@ const char *s1;
         return(save_to);
 }
 
+#endif /*NEED_STRDUP*/
+
