@@ -1,4 +1,4 @@
-/*Copyright (c) 1993-1997 Xerox Corporation.  All Rights Reserved.
+/*Copyright (c) 1993-1998 Xerox Corporation.  All Rights Reserved.
 
   Permission to use, copy, modify  and  distribute  without  charge
   this  software,  documentation, images, etc. is granted, provided
@@ -14,6 +14,8 @@
   Adam Stein (adam@iset.scan.mc.xerox.com)
 */
 
+#ifdef NEED_STRSTR
+
 #include <stdio.h>
 
 /*This function will find the first occurrence of a midstring (s2) in a
@@ -48,3 +50,4 @@ char *s1,*s2;
         return(NULL);
 }
 
+#endif /* NEED_STRSTR */
